@@ -17,6 +17,11 @@
 #'   provides redundant information in light of y-axis labels.
 #' @param low.color,high.color Colors for low and high ends of the gradient.
 #'   Defaults are colorblind-friendly.
+#' @param normal.curve Logical decides whether to super-impose a normal curve
+#'   using `stats::dnorm(mean(x), sd(x))`. Default is `FALSE`.
+#' @param normal.curve.color,normal.curve.linetype,normal.curve.size If
+#'   `normal.curve = TRUE`, then these arguments can be used to modify color
+#'   (Default: `"black"`), size (default: `1.0`), linetype (default: `"solid"`).
 #' @param bar.fill If `fill.gradient = FALSE`, then `bar.fill` decides which
 #'   color will uniformly fill all the bars in the histogram (Default:
 #'   `"grey50"`).
@@ -34,24 +39,26 @@
 #'
 #' @importFrom dplyr select bind_rows summarize mutate mutate_at mutate_if
 #' @importFrom dplyr group_by n arrange
+#' @importFrom rlang enquo as_name !!
 #' @importFrom jmv ttestOneS
 #' @importFrom WRS2 onesampb
-#' @importFrom scales percent
+#' @importFrom scales percent percent_format
+#' @importFrom stats dnorm
 #' @importFrom crayon green blue yellow red
 #'
 #' @examples
-#' 
+#'
 #' # most basic function call with the defaults
-#' # this is the only function where data argument can be `NULL`.
+#' # this is the **only** function where data argument can be `NULL`
 #' ggstatsplot::gghistostats(
 #'   x = ToothGrowth$len,
 #'   xlab = "Tooth length",
 #'   centrality.para = "median"
 #' )
-#' 
+#'
 #' # a detailed function call
 #' ggstatsplot::gghistostats(
-#'   data = datasets::iris,
+#'   data = iris,
 #'   x = Sepal.Length,
 #'   bar.measure = "mix",
 #'   type = "p",
@@ -106,31 +113,25 @@ gghistostats <- function(data = NULL,
                          test.value.linetype = "dashed",
                          test.line.labeller = TRUE,
                          test.k = 0,
+                         normal.curve = FALSE,
+                         normal.curve.color = "black",
+                         normal.curve.linetype = "solid",
+                         normal.curve.size = 1.0,
                          ggplot.component = NULL,
                          messages = TRUE) {
+
   # if data is not available then don't display any messages
   if (is.null(data)) {
     messages <- FALSE
   }
 
-  # if no color fill is to be displayed, set low and high color to white
-  if (!isTRUE(fill.gradient)) {
-    low.color <- bar.fill
-    high.color <- bar.fill
-  }
-
   # ================================= dataframe ==============================
 
   # preparing a dataframe out of provided inputs
   if (!is.null(data)) {
-    # preparing labels from given dataframe
-    lab.df <- colnames(dplyr::select(
-      .data = data,
-      !!rlang::enquo(x)
-    ))
     # if xlab is not provided, use the variable x name
     if (is.null(xlab)) {
-      xlab <- lab.df[1]
+      xlab <- rlang::as_name(rlang::ensym(x))
     }
 
     # if dataframe is provided
@@ -147,8 +148,8 @@ gghistostats <- function(data = NULL,
 
   # convert to a tibble and remove NAs from `x`
   data %<>%
-    tibble::as_tibble(x = .) %>%
-    dplyr::filter(.data = ., !is.na(x))
+    tidyr::drop_na(data = .) %>%
+    tibble::as_tibble(x = .)
 
   # Adding some binwidth sanity checking
   if (is.null(binwidth)) {
@@ -191,11 +192,16 @@ gghistostats <- function(data = NULL,
 
   # ============================= plot ====================================
 
+  # if no color fill is to be displayed, set low and high color to white
+  if (!isTRUE(fill.gradient)) {
+    low.color <- bar.fill
+    high.color <- bar.fill
+  }
+
   # preparing the basic layout of the plot based on whether counts or density
   # information is needed
 
   if (bar.measure == "count") {
-
     # only counts
     plot <- ggplot2::ggplot(
       data = data,
@@ -217,7 +223,6 @@ gghistostats <- function(data = NULL,
         high = high.color
       )
   } else if (bar.measure == "proportion") {
-
     # only proportion
     plot <- ggplot2::ggplot(
       data = data,
@@ -239,10 +244,9 @@ gghistostats <- function(data = NULL,
         high = high.color,
         labels = percent
       ) +
-      ggplot2::scale_y_continuous(labels = scales::percent) +
+      ggplot2::scale_y_continuous(labels = scales::percent_format(accuracy = 1)) +
       ggplot2::ylab("proportion")
   } else if (bar.measure == "density") {
-
     # only density
     plot <- ggplot2::ggplot(
       data = data,
@@ -263,8 +267,7 @@ gghistostats <- function(data = NULL,
         low = low.color,
         high = high.color
       )
-  } else if (bar.measure == "mix") {
-
+  } else if (bar.measure %in% c("mix", "both", "all")) {
     # all things combined
     plot <- ggplot2::ggplot(
       data = data,
@@ -287,8 +290,8 @@ gghistostats <- function(data = NULL,
       ) +
       ggplot2::scale_y_continuous(
         sec.axis = ggplot2::sec_axis(
-          trans = ~ . / nrow(x = data),
-          labels = scales::percent,
+          trans = ~ . / nrow(data),
+          labels = scales::percent_format(accuracy = 1),
           name = "proportion"
         )
       ) +
@@ -296,6 +299,64 @@ gghistostats <- function(data = NULL,
       ggplot2::guides(fill = FALSE)
   }
 
+  # ========================== normal curve ==================================
+
+  # if normal curve overlay  needs to be displayed
+  if (isTRUE(normal.curve)) {
+    # adding normal curve density
+    if (bar.measure == "density") {
+      plot <- plot +
+        ggplot2::stat_function(
+          fun = dnorm,
+          linetype = normal.curve.linetype,
+          color = normal.curve.color,
+          size = normal.curve.size,
+          na.rm = TRUE,
+          args = list(mean = mean(data$x), sd = sd(data$x))
+        )
+    }
+
+    # adding normal curve count & mix
+    if (bar.measure %in% c("mix", "count")) {
+      plot <- plot +
+        ggplot2::stat_function(
+          fun = function(x, mean, sd, n, bw) {
+            stats::dnorm(x = x, mean = mean, sd = sd) * n * bw
+          },
+          linetype = normal.curve.linetype,
+          color = normal.curve.color,
+          size = normal.curve.size,
+          na.rm = TRUE,
+          args = c(
+            mean = mean(data$x),
+            sd = sd(data$x),
+            n = length(data$x),
+            bw = binwidth
+          )
+        )
+    }
+
+    # adding normal curve proportion
+    if (bar.measure == "proportion") {
+      plot <- plot +
+        ggplot2::stat_function(
+          fun = function(x, mean, sd, n, bw) {
+            stats::dnorm(x = x, mean = mean, sd = sd) * bw
+          },
+          linetype = normal.curve.linetype,
+          color = normal.curve.color,
+          size = normal.curve.size,
+          na.rm = TRUE,
+          args = c(
+            mean = mean(data$x),
+            sd = sd(data$x),
+            n = length(data$x),
+            bw = binwidth
+          )
+        )
+    }
+  }
+
   # if bayes factor message needs to be displayed
   if (isTRUE(results.subtitle) &&
     type %in% c("parametric", "p") && isTRUE(bf.message)) {
@@ -356,12 +417,12 @@ gghistostats <- function(data = NULL,
   plot <- plot + ggplot.component
 
   # ============================= messages =================================
-  #
+
   # display normality test result as a message
   if (isTRUE(messages)) {
     normality_message(
       x = data$x,
-      lab = lab.df[1],
+      lab = xlab,
       k = k,
       output = "message"
     )
