@@ -6,17 +6,15 @@
 #'   resulting plots using `ggstatsplot::combine_plots`.
 #' @author Indrajeet Patil
 #'
-#' @param grouping.var Grouping variable.
-#' @param title.prefix Character specifying the prefix text for the fixed plot
-#'   title (name of each factor level) (Default: `"Group"`).
 #' @inheritParams ggdotplotstats
+#' @inheritParams grouped_ggbetweenstats
 #' @inheritDotParams combine_plots
 #'
 #' @importFrom dplyr select bind_rows summarize mutate mutate_at mutate_if
 #' @importFrom dplyr group_by n arrange
 #' @importFrom rlang !! enquo quo_name ensym
 #' @importFrom glue glue
-#' @importFrom purrr map set_names
+#' @importFrom purrr pmap
 #' @importFrom tidyr nest
 #'
 #' @seealso \code{\link{ggdotplotstats}}
@@ -25,13 +23,13 @@
 #' @inherit ggdotplotstats return details
 #'
 #' @examples
-#' 
+#'
 #' # for reproducibility
 #' set.seed(123)
-#' 
+#'
 #' # removing factor level with very few no. of observations
 #' df <- dplyr::filter(.data = ggplot2::mpg, cyl %in% c("4", "6", "8"))
-#' 
+#'
 #' # plot
 #' ggstatsplot::grouped_ggdotplotstats(
 #'   data = df,
@@ -40,9 +38,10 @@
 #'   grouping.var = "cyl",
 #'   test.value = 15.5,
 #'   title.prefix = "cylinder count",
-#'   ggplot.component = ggplot2::scale_y_continuous(
-#'     sec.axis = ggplot2::dup_axis(name = "percentile score"),
-#'     breaks = seq(0, 12, 2)
+#'   ggplot.component = ggplot2::scale_x_continuous(
+#'     sec.axis = ggplot2::dup_axis(),
+#'     limits = c(12, 24),
+#'     breaks = seq(12, 24, 2)
 #'   ),
 #'   messages = FALSE
 #' )
@@ -53,7 +52,7 @@ grouped_ggdotplotstats <- function(data,
                                    x,
                                    y,
                                    grouping.var,
-                                   title.prefix = "Group",
+                                   title.prefix = NULL,
                                    xlab = NULL,
                                    ylab = NULL,
                                    subtitle = NULL,
@@ -64,7 +63,7 @@ grouped_ggdotplotstats <- function(data,
                                    bf.message = FALSE,
                                    robust.estimator = "onestep",
                                    conf.level = 0.95,
-                                   nboot = 500,
+                                   nboot = 100,
                                    k = 2,
                                    ggtheme = ggplot2::theme_bw(),
                                    ggstatsplot.layer = TRUE,
@@ -93,6 +92,11 @@ grouped_ggdotplotstats <- function(data,
   # ensure the grouping variable works quoted or unquoted
   grouping.var <- rlang::ensym(grouping.var)
 
+  # if `title.prefix` is not provided, use the variable `grouping.var` name
+  if (is.null(title.prefix)) {
+    title.prefix <- rlang::as_name(grouping.var)
+  }
+
   # getting the dataframe ready
   df <-
     dplyr::select(
@@ -101,82 +105,63 @@ grouped_ggdotplotstats <- function(data,
       !!rlang::enquo(x),
       !!rlang::enquo(y)
     ) %>%
-    dplyr::mutate(
-      .data = .,
-      title.text = !!rlang::enquo(grouping.var)
-    )
+    tidyr::drop_na(data = .)
 
-  # creating a nested dataframe
+  # creating a list for grouped analysis
   df %<>%
-    dplyr::mutate_if(
-      .tbl = .,
-      .predicate = purrr::is_bare_character,
-      .funs = ~ as.factor(.)
-    ) %>%
-    dplyr::mutate_if(
-      .tbl = .,
-      .predicate = is.factor,
-      .funs = ~ base::droplevels(.)
-    ) %>%
-    dplyr::filter(.data = ., !is.na(!!rlang::enquo(grouping.var))) %>%
-    dplyr::arrange(.data = ., !!rlang::enquo(grouping.var)) %>%
-    dplyr::group_by(.data = ., !!rlang::enquo(grouping.var)) %>%
-    tidyr::nest(data = .)
+    grouped_list(data = ., grouping.var = !!rlang::enquo(grouping.var))
+
+  # list with basic arguments
+  flexiblelist <- list(
+    data = df,
+    x = rlang::quo_text(rlang::ensym(x)),
+    y = rlang::quo_text(rlang::ensym(y)),
+    title = glue::glue("{title.prefix}: {names(df)}")
+  )
 
   # creating a list of plots
   plotlist_purrr <-
-    df %>%
-    dplyr::mutate(
-      .data = .,
-      plots = data %>%
-        purrr::set_names(x = ., nm = !!rlang::enquo(grouping.var)) %>%
-        purrr::map(
-          .x = .,
-          .f = ~ ggstatsplot::ggdotplotstats(
-            data = .,
-            x = !!rlang::enquo(x),
-            y = !!rlang::enquo(y),
-            xlab = xlab,
-            ylab = ylab,
-            title = glue::glue("{title.prefix}: {as.character(.$title.text)}"),
-            subtitle = subtitle,
-            caption = caption,
-            type = type,
-            test.value = test.value,
-            bf.prior = bf.prior,
-            bf.message = bf.message,
-            robust.estimator = robust.estimator,
-            conf.level = conf.level,
-            nboot = nboot,
-            k = k,
-            results.subtitle = results.subtitle,
-            centrality.para = centrality.para,
-            centrality.color = centrality.color,
-            centrality.size = centrality.size,
-            centrality.linetype = centrality.linetype,
-            centrality.line.labeller = centrality.line.labeller,
-            centrality.k = centrality.k,
-            test.value.line = test.value.line,
-            test.value.color = test.value.color,
-            test.value.size = test.value.size,
-            test.value.linetype = test.value.linetype,
-            test.line.labeller = test.line.labeller,
-            test.k = test.k,
-            ggtheme = ggtheme,
-            ggstatsplot.layer = ggstatsplot.layer,
-            point.color = point.color,
-            point.size = point.size,
-            point.shape = point.shape,
-            ggplot.component = ggplot.component,
-            messages = messages
-          )
-        )
+    purrr::pmap(
+      .l = flexiblelist,
+      .f = ggstatsplot::ggdotplotstats,
+      xlab = xlab,
+      ylab = ylab,
+      subtitle = subtitle,
+      caption = caption,
+      type = type,
+      test.value = test.value,
+      bf.prior = bf.prior,
+      bf.message = bf.message,
+      robust.estimator = robust.estimator,
+      conf.level = conf.level,
+      nboot = nboot,
+      k = k,
+      results.subtitle = results.subtitle,
+      centrality.para = centrality.para,
+      centrality.color = centrality.color,
+      centrality.size = centrality.size,
+      centrality.linetype = centrality.linetype,
+      centrality.line.labeller = centrality.line.labeller,
+      centrality.k = centrality.k,
+      test.value.line = test.value.line,
+      test.value.color = test.value.color,
+      test.value.size = test.value.size,
+      test.value.linetype = test.value.linetype,
+      test.line.labeller = test.line.labeller,
+      test.k = test.k,
+      ggtheme = ggtheme,
+      ggstatsplot.layer = ggstatsplot.layer,
+      point.color = point.color,
+      point.size = point.size,
+      point.shape = point.shape,
+      ggplot.component = ggplot.component,
+      messages = messages
     )
 
   # combining the list of plots into a single plot
   combined_plot <-
     ggstatsplot::combine_plots(
-      plotlist = plotlist_purrr$plots,
+      plotlist = plotlist_purrr,
       ...
     )
 
