@@ -1,13 +1,14 @@
-#' @title A heteroscedastic one-way ANOVA for trimmed means with confidence
+#' #' @title A heteroscedastic one-way ANOVA for trimmed means with confidence
 #'   interval for effect size.
 #' @name t1way_ci
 #' @description Custom function to get confidence intervals for effect size
 #'   measure for robust ANOVA.
 #'
-#' @param data Dataframe from which variables specified are preferentially to be
-#'   taken.
-#' @param x The grouping variable.
-#' @param y The response - a vector of length the number of rows of `x`.
+#' @param data A dataframe (or a tibble) from which variables specified are to
+#'   be taken. A matrix or tables will **not** be accepted.
+#' @param x The grouping variable from the dataframe `data`.
+#' @param y The response (a.k.a. outcome or dependent) variable from the
+#'   dataframe `data`.
 #' @param nboot Number of bootstrap samples for computing effect size (Default:
 #'   `100`).
 #' @param tr Trim level for the mean when carrying out `robust` tests. If you
@@ -29,6 +30,20 @@
 #' @importFrom boot boot boot.ci
 #' @importFrom stats na.omit
 #'
+#' @examples
+#' \dontrun{
+#' set.seed(123)
+#' ggstatsplot:::t1way_ci(
+#'   data = dplyr::filter(ggplot2::msleep, vore != "insecti"),
+#'   x = vore,
+#'   y = brainwt,
+#'   tr = 0.05,
+#'   nboot = 50,
+#'   conf.level = 0.99,
+#'   conf.type = "perc"
+#' )
+#' }
+#'
 #' @keywords internal
 
 t1way_ci <- function(data,
@@ -46,6 +61,7 @@ t1way_ci <- function(data,
     y = !!rlang::enquo(y)
   ) %>%
     dplyr::filter(.data = ., !is.na(x), !is.na(y)) %>%
+    dplyr::mutate(.data = ., x = droplevels(as.factor(x))) %>%
     tibble::as_tibble(x = .)
 
   # running robust one-way anova
@@ -163,8 +179,23 @@ t1way_ci <- function(data,
 #' @importFrom boot boot boot.ci
 #' @importFrom stats na.omit
 #'
+#' @examples
+#' \dontrun{
+#' ggstatsplot:::yuend_ci(
+#'   data = dplyr::filter(
+#'     .data = ggstatsplot::iris_long,
+#'     condition %in% c("Sepal.Length", "Petal.Length")
+#'   ),
+#'   x = condition,
+#'   y = value,
+#'   nboot = 50,
+#'   tr = 0.2
+#' )
+#' }
+#'
 #' @keywords internal
 
+# function body
 yuend_ci <- function(data,
                      x,
                      y,
@@ -181,6 +212,7 @@ yuend_ci <- function(data,
       y = !!rlang::enquo(y)
     ) %>%
     dplyr::filter(.data = ., !is.na(x), !is.na(y)) %>%
+    dplyr::mutate(.data = ., x = droplevels(as.factor(x))) %>%
     tibble::as_tibble(x = .)
 
   # jamovi needs data to be wide format and not long format
@@ -297,12 +329,8 @@ yuend_ci <- function(data,
 #' @description Custom function to get confidence intervals for effect size
 #'   measure for parametric or non-parametric correlation coefficient.
 #'
-#' @param data Dataframe from which variables specified are preferentially to be
-#'   taken.
 #' @param x A vector containing the explanatory variable.
 #' @param y The response - a vector of length the number of rows of `x`.
-#' @param nboot Number of bootstrap samples for computing effect size (Default:
-#'   `100`).
 #' @inheritDotParams boot::boot
 #' @inheritParams stats::cor.test
 #' @inheritParams t1way_ci
@@ -314,8 +342,24 @@ yuend_ci <- function(data,
 #' @importFrom boot boot boot.ci
 #' @importFrom stats na.omit
 #'
+#' @examples
+#' \dontrun{
+#' ggstatsplot:::cor_test_ci(
+#'   data = ggplot2::msleep,
+#'   x = brainwt,
+#'   y = sleep_total,
+#'   nboot = 25,
+#'   conf.level = 0.99,
+#'   conf.type = "perc",
+#'   method = "spearman",
+#'   continuity = TRUE,
+#'   alternative = "greater"
+#' )
+#' }
+#'
 #' @keywords internal
 
+# function body
 cor_test_ci <- function(data,
                         x,
                         y,
@@ -457,18 +501,14 @@ cor_test_ci <- function(data,
 
 
 #' @title Chi-squared test of association with confidence interval for effect
-#'   size (Cramer's V).
+#'   size (Cramer's *V*).
 #' @name chisq_v_ci
 #' @description Custom function to get confidence intervals for effect size
 #'   measure for chi-squared test of association (Contingency Tables analyses,
 #'   i.e.).
 #'
-#' @param data Dataframe from which variables specified are preferentially to be
-#'   taken.
 #' @param rows The variable to use as the rows in the contingency table.
 #' @param cols the variable to use as the columns in the contingency table.
-#' @param nboot Number of bootstrap samples for computing effect size (Default:
-#'   `25`).
 #' @inheritParams t1way_ci
 #' @inheritDotParams boot::boot
 #'
@@ -480,16 +520,29 @@ cor_test_ci <- function(data,
 #' @importFrom boot boot.ci
 #' @importFrom stats na.omit
 #'
+#' @examples
+#' \dontrun{
+#' ggstatsplot:::chisq_v_ci(
+#'   data = ggstatsplot::Titanic_full,
+#'   rows = Sex,
+#'   cols = Survived,
+#'   nboot = 12,
+#'   conf.level = 0.90,
+#'   conf.type = "norm"
+#' )
+#' }
+#'
 #' @keywords internal
 
 # function body
 chisq_v_ci <- function(data,
                        rows,
                        cols,
-                       nboot = 25,
+                       nboot = 100,
                        conf.level = 0.95,
                        conf.type = "norm",
                        ...) {
+
   # creating a dataframe from entered data
   data <-
     dplyr::select(
@@ -609,12 +662,8 @@ chisq_v_ci <- function(data,
 #'   confidence intervals. Additionally, it also includes information about
 #'   sample size, bending constant, no. of bootstrap samples, etc.
 #'
-#' @param data Dataframe from which variables specified are preferentially to be
-#'   taken.
 #' @param x A vector containing the explanatory variable.
 #' @param y The response - a vector of length the number of rows of `x`.
-#' @param nboot Number of bootstrap samples for computing effect size (Default:
-#'   `100`).
 #' @param beta bending constant (Default: `0.1`). For more, see `?WRS2::pbcor`.
 #' @inheritParams t1way_ci
 #' @inheritDotParams boot::boot
@@ -626,8 +675,22 @@ chisq_v_ci <- function(data,
 #' @importFrom boot boot boot.ci
 #' @importFrom stats na.omit
 #'
+#' @examples
+#' \dontrun{
+#' ggstatsplot:::robcor_ci(
+#'   data = mtcars,
+#'   x = "hp",
+#'   y = "mpg",
+#'   beta = .01,
+#'   nboot = 125,
+#'   conf.level = .99,
+#'   conf.type = c("basic")
+#' )
+#' }
+#'
 #' @keywords internal
 
+# function body
 robcor_ci <- function(data,
                       x,
                       y,
@@ -752,6 +815,18 @@ robcor_ci <- function(data,
 #' @importFrom boot boot boot.ci
 #' @importFrom stats na.omit
 #'
+#' @examples
+#' \dontrun{
+#' ggstatsplot:::kw_eta_h_ci(
+#'   data = ggplot2::msleep,
+#'   x = vore,
+#'   y = sleep_rem,
+#'   nboot = 100,
+#'   conf.level = 0.90,
+#'   conf.type = "basic"
+#' )
+#' }
+#'
 #' @keywords internal
 
 # function to get confidence intervals
@@ -771,6 +846,7 @@ kw_eta_h_ci <- function(data,
       y = !!rlang::enquo(y)
     ) %>%
     dplyr::filter(.data = ., !is.na(x), !is.na(y)) %>%
+    dplyr::mutate(.data = ., x = droplevels(as.factor(x))) %>%
     tibble::as_tibble(x = .)
 
   # custom function to get eta-squared value
