@@ -8,28 +8,28 @@
 #' \dontrun{
 #' # show all columns in a tibble
 #' options(tibble.width = Inf)
-#' 
+#'
 #' # for reproducibility
 #' set.seed(123)
-#' 
+#'
 #' #------------------------- models with *t*-statistic ------------------
 #' # model with t-statistic
 #' ggstatsplot:::ggcoefstats_label_maker(x = broom::tidy(stats::lm(
 #'   data = mtcars, formula = wt ~ cyl * mpg
 #' )), statistic = "t")
-#' 
+#'
 #' # (in case `x` is not a dataframe, no need to specify `statistic` argument;
 #' # this will be figured out by the function itself)
-#' 
+#'
 #' #------------------------- models with *t*-statistic ------------------
-#' 
+#'
 #' # dataframe
 #' clotting <- data.frame(
 #'   u = c(5, 10, 15, 20, 30, 40, 60, 80, 100),
 #'   lot1 = c(118, 58, 42, 35, 27, 25, 21, 19, 18),
 #'   lot2 = c(69, 35, 26, 21, 18, 16, 13, 12, 12)
 #' )
-#' 
+#'
 #' # model
 #' mod <-
 #'   stats::glm(
@@ -37,7 +37,7 @@
 #'     data = clotting,
 #'     family = Gamma
 #'   )
-#' 
+#'
 #' # model with t-statistic
 #' ggstatsplot:::ggcoefstats_label_maker(
 #'   x = mod,
@@ -47,30 +47,30 @@
 #'     conf.level = 0.95
 #'   )
 #' )
-#' 
+#'
 #' #------------------------- models with *z*-statistic --------------------
-#' 
+#'
 #' # preparing dataframe
 #' counts <- c(18, 17, 15, 20, 10, 20, 25, 13, 12)
 #' outcome <- gl(3, 1, 9)
 #' treatment <- gl(3, 3)
 #' d.AD <- data.frame(treatment, outcome, counts)
-#' 
+#'
 #' # model
 #' mod <- stats::glm(
 #'   formula = counts ~ outcome + treatment,
 #'   family = poisson(),
 #'   data = d.AD
 #' )
-#' 
+#'
 #' # creating tidy dataframe with label column
 #' ggstatsplot:::ggcoefstats_label_maker(x = mod, tidy_df = broom::tidy(mod))
-#' 
+#'
 #' #------------------------- models with *f*-statistic --------------------
 #' # creating a model object
 #' op <- options(contrasts = c("contr.helmert", "contr.poly"))
 #' npk.aov <- stats::aov(formula = yield ~ block + N * P * K, data = npk)
-#' 
+#'
 #' # converting to a dataframe using
 #' tidy_df <- ggstatsplot::lm_effsize_ci(
 #'   object = npk.aov,
@@ -79,7 +79,7 @@
 #'   nboot = 50
 #' ) %>%
 #'   dplyr::rename(.data = ., estimate = omegasq, statistic = F.value)
-#' 
+#'
 #' # including a new column with a label
 #' ggstatsplot:::ggcoefstats_label_maker(
 #'   x = npk.aov,
@@ -88,7 +88,7 @@
 #'   partial = FALSE
 #' )
 #' }
-#' 
+#'
 #' @keywords internal
 
 # function body
@@ -99,6 +99,7 @@ ggcoefstats_label_maker <- function(x,
                                     k = 2,
                                     effsize = "eta",
                                     partial = TRUE) {
+  # ================================ list of objects ==========================
 
   # dataframe objects
   df.mods <- c(
@@ -114,7 +115,9 @@ ggcoefstats_label_maker <- function(x,
       "biglm",
       "cch",
       "coeftest",
+      "drc",
       "felm",
+      "gam",
       "gamlss",
       "garch",
       "gls",
@@ -149,6 +152,8 @@ ggcoefstats_label_maker <- function(x,
       "ergm",
       "glmmadmb",
       "glmmTMB",
+      "lavaan",
+      "mjoint",
       "mle2",
       "survreg"
     )
@@ -159,7 +164,6 @@ ggcoefstats_label_maker <- function(x,
     "aovlist",
     "anova",
     "Gam",
-    "gam",
     "manova"
   )
 
@@ -171,6 +175,22 @@ ggcoefstats_label_maker <- function(x,
     "glmRob"
   )
 
+  # t-statistic
+  g.t.mods <- c(
+    "quasi",
+    "gaussian",
+    "quasibinomial",
+    "quasipoisson",
+    "Gamma",
+    "inverse.gaussian"
+  )
+
+  # z-statistic
+  g.z.mods <- c(
+    "binomial",
+    "poisson"
+  )
+
   # ================================ dataframe ================================
   if (class(x)[[1]] %in% df.mods) {
     tidy_df <- tfz_labeller(
@@ -203,14 +223,7 @@ ggcoefstats_label_maker <- function(x,
     # ================ t/z-statistic labels ===================================
   } else if (class(x)[[1]] %in% g.mods) {
     if (class(x)[[1]] == "glm") {
-      if (summary(x)$family$family[[1]] %in% c(
-        "quasi",
-        "gaussian",
-        "quasibinomial",
-        "quasipoisson",
-        "Gamma",
-        "inverse.gaussian"
-      )) {
+      if (summary(x)$family$family[[1]] %in% g.t.mods) {
         tidy_df %<>%
           tfz_labeller(
             tidy_df = .,
@@ -218,8 +231,7 @@ ggcoefstats_label_maker <- function(x,
             statistic = "t",
             k = k
           )
-      } else if (summary(x)$family$family[[1]] %in%
-        c("binomial", "poisson")) {
+      } else if (summary(x)$family$family[[1]] %in% g.z.mods) {
         tidy_df %<>%
           tfz_labeller(
             tidy_df = .,
@@ -229,14 +241,7 @@ ggcoefstats_label_maker <- function(x,
           )
       }
     } else if (class(x)[[1]] == "glmerMod") {
-      if (summary(x)$family[[1]] %in% c(
-        "quasi",
-        "gaussian",
-        "quasibinomial",
-        "quasipoisson",
-        "Gamma",
-        "inverse.gaussian"
-      )) {
+      if (summary(x)$family[[1]] %in% g.t.mods) {
         tidy_df %<>%
           tfz_labeller(
             tidy_df = .,
@@ -244,7 +249,7 @@ ggcoefstats_label_maker <- function(x,
             statistic = "t",
             k = k
           )
-      } else if (summary(x)$family[[1]] %in% c("binomial", "poisson")) {
+      } else if (summary(x)$family[[1]] %in% g.z.mods) {
         tidy_df %<>%
           tfz_labeller(
             tidy_df = .,
@@ -254,14 +259,7 @@ ggcoefstats_label_maker <- function(x,
           )
       }
     } else if (class(x)[[1]] == "glmRob") {
-      if (x$family[[1]] %in% c(
-        "quasi",
-        "gaussian",
-        "quasibinomial",
-        "quasipoisson",
-        "Gamma",
-        "inverse.gaussian"
-      )) {
+      if (x$family[[1]] %in% g.t.mods) {
         tidy_df %<>%
           tfz_labeller(
             tidy_df = .,
@@ -269,7 +267,7 @@ ggcoefstats_label_maker <- function(x,
             statistic = "t",
             k = k
           )
-      } else if (x$family[[1]] %in% c("binomial", "poisson")) {
+      } else if (x$family[[1]] %in% g.z.mods) {
         tidy_df %<>%
           tfz_labeller(
             tidy_df = .,
@@ -430,101 +428,41 @@ tfz_labeller <- function(tidy_df,
     # which effect size is needed?
     if (effsize == "eta") {
       if (isTRUE(partial)) {
-        tidy_df %<>%
-          purrrlyr::by_row(
-            .d = .,
-            ..f = ~ paste(
-              "list(~italic(F)",
-              "(",
-              .$df1,
-              "*\",\"*",
-              .$df2,
-              ")==",
-              .$statistic,
-              ", ~italic(p)",
-              .$p.value.formatted2,
-              ", ~italic(eta)[p]^2==",
-              specify_decimal_p(x = .$estimate, k = k),
-              ")",
-              sep = ""
-            ),
-            .collate = "rows",
-            .to = "label",
-            .labels = TRUE
-          )
+        tidy_df$effsize.text <- list(quote(italic(eta)[p]^2))
       } else {
-        tidy_df %<>%
-          purrrlyr::by_row(
-            .d = .,
-            ..f = ~ paste(
-              "list(~italic(F)",
-              "(",
-              .$df1,
-              "*\",\"*",
-              .$df2,
-              ")==",
-              .$statistic,
-              ", ~italic(p)",
-              .$p.value.formatted2,
-              ", ~italic(eta)^2==",
-              specify_decimal_p(x = .$estimate, k = k),
-              ")",
-              sep = ""
-            ),
-            .collate = "rows",
-            .to = "label",
-            .labels = TRUE
-          )
+        tidy_df$effsize.text <- list(quote(italic(eta)^2))
       }
     } else if (effsize == "omega") {
       if (isTRUE(partial)) {
-        tidy_df %<>%
-          purrrlyr::by_row(
-            .d = .,
-            ..f = ~ paste(
-              "list(~italic(F)",
-              "(",
-              .$df1,
-              "*\",\"*",
-              .$df2,
-              ")==",
-              .$statistic,
-              ", ~italic(p)",
-              .$p.value.formatted2,
-              ", ~italic(omega)[p]^2==",
-              specify_decimal_p(x = .$estimate, k = k),
-              ")",
-              sep = ""
-            ),
-            .collate = "rows",
-            .to = "label",
-            .labels = TRUE
-          )
+        tidy_df$effsize.text <- list(quote(italic(omega)[p]^2))
       } else {
-        tidy_df %<>%
-          purrrlyr::by_row(
-            .d = .,
-            ..f = ~ paste(
-              "list(~italic(F)",
-              "(",
-              .$df1,
-              "*\",\"*",
-              .$df2,
-              ")==",
-              .$statistic,
-              ", ~italic(p)",
-              .$p.value.formatted2,
-              ", ~italic(omega)^2==",
-              specify_decimal_p(x = .$estimate, k = k),
-              ")",
-              sep = ""
-            ),
-            .collate = "rows",
-            .to = "label",
-            .labels = TRUE
-          )
+        tidy_df$effsize.text <- list(quote(italic(omega)^2))
       }
     }
+
+    # which effect size is needed?
+    tidy_df %<>%
+      purrrlyr::by_row(
+        .d = .,
+        ..f = ~ paste(
+          "list(~italic(F)",
+          "(",
+          .$df1,
+          "*\",\"*",
+          .$df2,
+          ")==",
+          .$statistic,
+          ", ~italic(p)",
+          .$p.value.formatted2,
+          ", ~", .$effsize.text, "==",
+          specify_decimal_p(x = .$estimate, k = k),
+          ")",
+          sep = ""
+        ),
+        .collate = "rows",
+        .to = "label",
+        .labels = TRUE
+      )
   }
 
   # convert to tibble
@@ -544,45 +482,74 @@ tfz_labeller <- function(tidy_df,
 #'   (corresponding estimates of coefficients or other quantities of interest)
 #'   and `std.error` (the standard error of the regression term).
 #' @param output  Character describing the desired output. If `"subtitle"`, a
-#'   formatted subtitle will be returned. The other option is to return `"tidy"`
-#'   data frame with coefficients.
+#'   formatted subtitle with summary effect and statistical details will be
+#'   returned, and if `"caption"`, expression containing details from model
+#'   summary will be returned. The other option is to return `"tidy"` data frame
+#'   with coefficients or `"glance"` dataframe with model summaries.
 #' @inheritParams ggbetweenstats
 #' @param ... Additional arguments (ignored).
 #'
 #' @importFrom metafor rma
 #'
 #' @examples
-#' # set up
-#' set.seed(123)
-#' library(ggstatsplot)
-#' library(gapminder)
-#' 
-#' # saving results from regression
-#' df_results <- purrr::pmap(
-#'   .l = list(
-#'     data = list(gapminder::gapminder),
-#'     formula = list(scale(lifeExp) ~ scale(gdpPercap)),
-#'     grouping.vars = alist(continent),
-#'     output = list("tidy", "glance")
-#'   ),
-#'   .f = groupedstats::grouped_lm
-#' ) %>%
-#'   dplyr::full_join(x = .[[1]], y = .[[2]], by = "continent") %>%
-#'   dplyr::filter(.data = ., term != "(Intercept)")
-#' 
+#' # let's create a dataframe
+#' df_results <-
+#'   structure(
+#'     .Data = list(estimate = c(
+#'       0.382047603321706, 0.780783111514665,
+#'       0.425607573765058, 0.558365541235078, 0.956473848429961
+#'     ), std.error = c(
+#'       0.0465576338644502,
+#'       0.0330218199731529, 0.0362834986178494, 0.0480571500648261, 0.062215818388157
+#'     ), t.value = c(
+#'       8.20590677855356, 23.6444603038067, 11.7300588415607,
+#'       11.6187818146078, 15.3734833553524
+#'     ), conf.low = c(
+#'       0.290515146096969,
+#'       0.715841986960399, 0.354354575031406, 0.46379116008131, 0.827446138277154
+#'     ), conf.high = c(
+#'       0.473580060546444, 0.845724236068931, 0.496860572498711,
+#'       0.652939922388847, 1.08550155858277
+#'     ), p.value.x = c(
+#'       3.28679518728519e-15,
+#'       4.04778497135963e-75, 7.59757330804449e-29, 5.45155840151592e-26,
+#'       2.99171217913312e-13
+#'     ), df.residual = c(
+#'       394L, 358L, 622L, 298L,
+#'       22L
+#'     )),
+#'     row.names = c(NA, -5L),
+#'     class = c("tbl_df", "tbl", "data.frame")
+#'   )
+#'
 #' # making subtitle
 #' ggstatsplot::subtitle_meta_ggcoefstats(
 #'   data = df_results,
 #'   k = 3,
 #'   messages = FALSE
 #' )
-#' 
+#'
 #' # getting tidy data frame with coefficients
 #' ggstatsplot::subtitle_meta_ggcoefstats(
 #'   data = df_results,
 #'   messages = FALSE,
 #'   output = "tidy"
 #' )
+#'
+#' # making caption
+#' ggstatsplot::subtitle_meta_ggcoefstats(
+#'   data = df_results,
+#'   k = 2,
+#'   messages = FALSE,
+#'   output = "caption"
+#' )
+#'
+#' # getting dataframe with model summary
+#' ggstatsplot::subtitle_meta_ggcoefstats(
+#'   data = df_results,
+#'   messages = FALSE,
+#'   output = "glance"
+#' )
 #' @export
 
 # function body
@@ -590,8 +557,11 @@ subtitle_meta_ggcoefstats <- function(data,
                                       k = 2,
                                       messages = TRUE,
                                       output = "subtitle",
+                                      caption = NULL,
                                       ...) {
 
+  #----------------------- input checking ------------------------------------
+
   # check if the two columns needed are present
   if (sum(c("estimate", "std.error") %in% names(data)) != 2) {
     # inform the user that skipping labels for the same reason
@@ -605,6 +575,8 @@ subtitle_meta_ggcoefstats <- function(data,
     )
   }
 
+  #----------------------- meta-analysis ------------------------------------
+
   # object from meta-analysis
   meta_res <- metafor::rma(
     yi = estimate,
@@ -626,8 +598,10 @@ subtitle_meta_ggcoefstats <- function(data,
     print(summary(meta_res))
   }
 
+  #----------------------- tidy output and subtitle ---------------------------
+
   # create a dataframe with coeffcients
-  df_coef <- coef(summary(meta_res)) %>%
+  df_tidy <- coef(summary(meta_res)) %>%
     tibble::as_tibble(x = .) %>%
     dplyr::rename(
       .data = .,
@@ -652,7 +626,7 @@ subtitle_meta_ggcoefstats <- function(data,
     base::substitute(
       expr =
         paste(
-          "Meta-analytic effect: ",
+          "Summary effect: ",
           beta,
           " = ",
           estimate,
@@ -675,20 +649,80 @@ subtitle_meta_ggcoefstats <- function(data,
           pvalue
         ),
       env = base::list(
-        estimate = specify_decimal_p(x = df_coef$estimate, k = k),
-        LL = specify_decimal_p(x = df_coef$conf.low, k = k),
-        UL = specify_decimal_p(x = df_coef$conf.high, k = k),
-        zvalue = specify_decimal_p(x = df_coef$z.value, k = k),
-        se = specify_decimal_p(x = df_coef$std.error, k = k),
-        pvalue = specify_decimal_p(x = df_coef$p.value, k = k, p.value = TRUE)
+        estimate = specify_decimal_p(x = df_tidy$estimate, k = k),
+        LL = specify_decimal_p(x = df_tidy$conf.low, k = k),
+        UL = specify_decimal_p(x = df_tidy$conf.high, k = k),
+        zvalue = specify_decimal_p(x = df_tidy$z.value, k = k),
+        se = specify_decimal_p(x = df_tidy$std.error, k = k),
+        pvalue = specify_decimal_p(x = df_tidy$p.value, k = k, p.value = TRUE)
       )
     )
 
+  #----------------------- input checking ------------------------------------
+
+  df_glance <- with(
+    data = meta_res,
+    expr = tibble::tibble(
+      tau2 = tau2,
+      se.tau2 = se.tau2,
+      k = k,
+      p = p,
+      m = m,
+      QE = QE,
+      QEp = QEp,
+      QM = QM,
+      QMp = QMp,
+      I2 = I2,
+      H2 = H2,
+      int.only = int.only
+    )
+  )
+
+  # preparing the subtitle
+  caption <-
+    base::substitute(
+      atop(displaystyle(top.text),
+        expr =
+          paste(
+            "Heterogeneity: ",
+            italic("Q"),
+            "(",
+            df,
+            ") = ",
+            Q,
+            ", ",
+            italic("p"),
+            " = ",
+            pvalue,
+            ", ",
+            tau["REML"]^2,
+            " = ",
+            tau2,
+            ", ",
+            "I"^2,
+            " = ",
+            I2
+          )
+      ),
+      env = base::list(
+        top.text = caption,
+        Q = specify_decimal_p(x = df_glance$QE, k = 0L),
+        df = specify_decimal_p(x = (df_glance$k - 1), k = 0L),
+        pvalue = specify_decimal_p(x = df_glance$QEp, k = k, p.value = TRUE),
+        tau2 = specify_decimal_p(x = df_glance$tau2, k = k),
+        I2 = paste(specify_decimal_p(x = df_glance$I2, k = 2L), "%", sep = "")
+      )
+    )
+
+  #---------------------------- output ---------------------------------------
+
   if (output == "subtitle") {
-    # return the subtitle
     return(subtitle)
   } else if (output == "tidy") {
-    # tidy data frame with coefficients
-    return(df_coef)
+    return(df_tidy)
+  } else if (output == "caption") {
+    return(caption)
+  } else if (output == "glance") {
+    return(df_glance)
   }
 }
