@@ -1,4 +1,3 @@
-# context ------------------------------------------------------------
 context(desc = "ggscatterstats")
 
 # pearson's r with NAs ---------------------------------------------
@@ -6,6 +5,8 @@ context(desc = "ggscatterstats")
 testthat::test_that(
   desc = "checking ggscatterstats - without NAs - pearson's r",
   code = {
+    testthat::skip_on_cran()
+
     # creating the plot
     set.seed(123)
     p <-
@@ -76,6 +77,32 @@ testthat::test_that(
     testthat::expect_equal(p$plot_env$y_median, 1.6700, tolerance = 0.002)
     testthat::expect_equal(p$plot_env$y_mean, 166.1363, tolerance = 0.002)
 
+    # checking geoms
+    testthat::expect_equal(
+      class(pb$data[[5]]$label[[1]]),
+      "call"
+    )
+    testthat::expect_equal(
+      pb$data[[5]]$label[[1]],
+      ggplot2::expr("mean" == "10.43")
+    )
+    testthat::expect_equal(pb$data[[5]]$x[[1]], 10.43373, tolerance = 0.001)
+    testthat::expect_equal(pb$data[[5]]$y[[1]], 3693.693, tolerance = 0.001)
+    testthat::expect_equal(
+      class(pb$data[[6]]$label[[1]]),
+      "call"
+    )
+    testthat::expect_equal(
+      pb$data[[6]]$label[[1]],
+      ggplot2::expr("mean" == "166.14")
+    )
+    testthat::expect_equal(pb$data[[6]]$x[[1]], 13.625, tolerance = 0.001)
+    testthat::expect_equal(pb$data[[6]]$y[[1]], 166.1363, tolerance = 0.001)
+
+    # checking intercepts
+    testthat::expect_equal(pb$data[[3]]$xintercept[[1]], 10.43373, tolerance = 0.001)
+    testthat::expect_equal(pb$data[[4]]$yintercept[[1]], 166.1363, tolerance = 0.001)
+
     # subtitle
     set.seed(123)
     p_subtitle <- ggstatsplot::subtitle_ggscatterstats(
@@ -97,7 +124,9 @@ testthat::test_that(
           "(BF"["01"],
           ") = ",
           "-2.23",
-          ", Prior width = ",
+          ", ",
+          italic("r")["Cauchy"],
+          " = ",
           "0.71"
         )
       ))
@@ -118,6 +147,8 @@ testthat::test_that(
 testthat::test_that(
   desc = "checking ggscatterstats - without NAs - spearman's rho",
   code = {
+    testthat::skip_on_cran()
+
     # creating the plot
     set.seed(123)
     p <-
@@ -152,6 +183,8 @@ testthat::test_that(
 testthat::test_that(
   desc = "checking ggscatterstats - without NAs - percentage bend",
   code = {
+    testthat::skip_on_cran()
+
     # creating the plot
     set.seed(123)
     p <-
@@ -212,6 +245,7 @@ testthat::test_that(
 testthat::test_that(
   desc = "checking median display",
   code = {
+    testthat::skip_on_cran()
 
     # creating the plot
     set.seed(123)
@@ -330,6 +364,8 @@ testthat::test_that(
 testthat::test_that(
   desc = "aesthetic modifications work",
   code = {
+    testthat::skip_on_cran()
+
     # creating the plot
     set.seed(123)
     p <- ggstatsplot::ggscatterstats(
@@ -483,6 +519,8 @@ testthat::test_that(
 testthat::test_that(
   desc = "class of object",
   code = {
+    testthat::skip_on_cran()
+
     # creating the messages
     set.seed(123)
     p_message1 <- capture.output(
