@@ -5,16 +5,15 @@ context("helpers_bf_tests")
 testthat::test_that(
   desc = "bayes factor plus posterior checks (correlation)",
   code = {
+    testthat::skip_on_cran()
+
     # creating a dataframe
     set.seed(123)
     df <- suppressMessages(ggstatsplot::bf_extractor(
       BayesFactor::correlationBF(
         x = ggplot2::msleep$brainwt,
         y = ggplot2::msleep$sleep_total
-      ),
-      posterior = TRUE,
-      iterations = 500,
-      cred.int = 0.90
+      )
     ))
 
     # check bayes factor values
@@ -23,14 +22,6 @@ testthat::test_that(
     testthat::expect_equal(df$log_e_bf10, -df$log_e_bf01, tolerance = 0.001)
     testthat::expect_equal(df$log_10_bf10, 0.9537841, tolerance = 0.001)
     testthat::expect_equal(df$log_10_bf10, -df$log_10_bf01, tolerance = 0.001)
-
-    # check posterior values
-    testthat::expect_equal(df$posterior.median, -0.34, tolerance = 0.01)
-    testthat::expect_equal(df$posterior.sd, 0.13, tolerance = 0.01)
-    testthat::expect_equal(df$posterior.std.error, 0.00411, tolerance = 0.001)
-    testthat::expect_equal(df$HDI.low, -0.5403865, tolerance = 0.001)
-    testthat::expect_equal(df$HDI.high, -0.1230767, tolerance = 0.001)
-    testthat::expect_equal(df$cred.int, 0.90, tolerance = 0.01)
   }
 )
 
@@ -39,6 +30,8 @@ testthat::test_that(
 testthat::test_that(
   desc = "bayes factor plus posterior checks (paired t-test)",
   code = {
+    testthat::skip_on_cran()
+
     # creating a dataframe
     set.seed(123)
     data("bugs", package = "jmv")
@@ -50,10 +43,7 @@ testthat::test_that(
         y = dat$HDHF,
         rscale = 0.8,
         paired = TRUE
-      ),
-      posterior = TRUE,
-      iterations = 500,
-      cred.int = 0.95
+      )
     ))
 
     # creating a tidy dataframe
@@ -81,14 +71,6 @@ testthat::test_that(
     # checking if two usages of the function are producing the same results
     testthat::expect_equal(df$bf10, df_results$bf10, tolerance = 0.001)
     testthat::expect_equal(df$log_e_bf01, df_results$log_e_bf01, tolerance = 0.001)
-
-    # check posterior values
-    testthat::expect_equal(df$posterior.median, -0.016, tolerance = 0.01)
-    testthat::expect_equal(df$posterior.sd, 47.6, tolerance = 0.01)
-    testthat::expect_equal(df$posterior.std.error, 1.064368, tolerance = 0.001)
-    testthat::expect_equal(df$HDI.low, -1.778363, tolerance = 0.001)
-    testthat::expect_equal(df$HDI.high, 10.33179, tolerance = 0.001)
-    testthat::expect_equal(df$cred.int, 0.95, tolerance = 0.01)
   }
 )
 
@@ -99,6 +81,8 @@ testthat::test_that(
 testthat::test_that(
   desc = "bayes factor plus posterior checks (paired t-test)",
   code = {
+    testthat::skip_on_cran()
+
     # creating a dataframe
     set.seed(123)
     df <- suppressMessages(ggstatsplot::bf_extractor(
@@ -106,10 +90,7 @@ testthat::test_that(
         x = iris$Petal.Length,
         mu = 5.5,
         rscale = 0.99
-      ),
-      posterior = TRUE,
-      iterations = 500,
-      cred.int = 0.95
+      )
     ))
 
     # extracting results from where this function is implemented
@@ -131,14 +112,6 @@ testthat::test_that(
     # checking if two usages of the function are producing the same results
     testthat::expect_equal(df$bf10, df_results$bf10, tolerance = 0.001)
     testthat::expect_equal(df$log_e_bf01, df_results$log_e_bf01, tolerance = 0.001)
-
-    # check posterior values
-    testthat::expect_equal(df$posterior.median, 3.23, tolerance = 0.01)
-    testthat::expect_equal(df$posterior.sd, 267.03, tolerance = 0.01)
-    testthat::expect_equal(df$posterior.std.error, 5.970972, tolerance = 0.001)
-    testthat::expect_equal(df$HDI.low, 0.4319726, tolerance = 0.001)
-    testthat::expect_equal(df$HDI.high, 13.50321, tolerance = 0.001)
-    testthat::expect_equal(df$cred.int, 0.95, tolerance = 0.01)
   }
 )
 
@@ -149,6 +122,7 @@ testthat::test_that(
 testthat::test_that(
   desc = "bayes factor plus posterior checks (contingency tab)",
   code = {
+    testthat::skip_on_cran()
 
     # extracting results from where this function is implemented
     set.seed(123)
@@ -157,10 +131,7 @@ testthat::test_that(
         x = table(mtcars$am, mtcars$cyl),
         sampleType = "jointMulti",
         fixedMargin = "rows"
-      ),
-      posterior = TRUE,
-      iterations = 500,
-      cred.int = 0.95
+      )
     ))
 
     # extracting results from where this function is implemented
@@ -184,14 +155,6 @@ testthat::test_that(
     # checking if two usages of the function are producing the same results
     testthat::expect_equal(df$bf10, df_results$bf10, tolerance = 0.001)
     testthat::expect_equal(df$log_e_bf01, df_results$log_e_bf01, tolerance = 0.001)
-
-    # check posterior values
-    testthat::expect_equal(df$posterior.median, 0.13, tolerance = 0.01)
-    testthat::expect_equal(df$posterior.sd, 0.11, tolerance = 0.01)
-    testthat::expect_equal(df$posterior.std.error, 0.002008316, tolerance = 0.001)
-    testthat::expect_equal(df$HDI.low, 0.01865475, tolerance = 0.001)
-    testthat::expect_equal(df$HDI.high, 0.3931479, tolerance = 0.001)
-    testthat::expect_identical(class(df)[[1]], "tbl_df")
   }
 )
 
@@ -201,8 +164,10 @@ testthat::test_that(
 testthat::test_that(
   desc = "bayes factor caption maker check",
   code = {
+    testthat::skip_on_cran()
 
     # bayes factor results
+    set.seed(123)
     bf_results <- tibble::tribble(
       ~log_e_bf01, ~bf.prior,
       1.1, 0.88
@@ -227,7 +192,9 @@ testthat::test_that(
           "(BF"["01"],
           ") = ",
           "1.100",
-          ", Prior width = ",
+          ", ",
+          italic("r")["Cauchy"],
+          " = ",
           "0.880"
         )
       ))
